/*
 * Copyright (C) 2004
 *	Tommy Scheunemann <net@arrishq.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "wmconfig.h"
#include "prototypes.h"
#include "package.h"
#include <stdio.h>

/* Please note:
 This output is used by the Tcl/Tk application launcher.
*/

/*
 Output function for the application launcher
*/

void output_menus(struct group *root)
{
 struct item *item;
 if (root == (struct group *)NULL)
  return;

/* create entries for menus */
 item = root->items;

/* read the complete input data and create menus */

 while (item->type != 0) {
  if (item->type == ITEM_MENU) {
   struct group *tmp;
   tmp = (struct group *)item->data;

   /* Remove slashes and whitespaces from the name and
      lower the entire name because Tk don't likes
      Wm/C onfiG but it likes wm_c_onfig */

   printf(".wmconfig.menu add cascade -label \"%s\" -menu .wmconfig.menu.%s\n", tmp->name, tk_string(tmp->name));
  }
  item++;
 }
 item = root->items;
 while (item->type != 0) {
  if (item->type == ITEM_MENU)
   output_menus(item->data);
  item++;
 }
 return;
}

/* This creates the application entries */

void output_entries(struct group *root, char *use_term)
{
 struct item *item;
 if (root == (struct group *)NULL)
  return;

 item = root->items;
 
/* read the complete input data and create menus */

 while (item->type != 0) {
  if (item->type == ITEM_MENU) {
   struct group *tmp;
   tmp = (struct group *)item->data;

/* create entries for submenus */
   printf("menu .wmconfig.menu.%s\n", tk_string(tmp->name));
  }
  item++;
 }

 item = root->items;
 
/* read the input data and create the application entries */

 while (item->type != 0) {
  if (item->type == ITEM_APP) {
   struct package *app;
   app = (struct package *)item->data;

   /* Check for terminal option and do not create quit or restart entries */

   if (! app->restart)

    /* Check for entries promoted to the root menu and correct the menu
       name */

    if (app->group == root->name) {
     if (app->name && app->exec && app->terminal)
      printf(" .wmconfig.menu add command -label \"%s\" -command \"exec %s -e %s\"\n", app->name, use_term, app->exec);
     else
      printf(" .wmconfig.menu add command -label \"%s\" -command \"exec %s\"\n", app->name, app->exec);
    } else {

     /* ... or create a normal menu entry */

     if (app->name && app->exec && app->terminal)
      printf(" .wmconfig.menu.%s add command -label \"%s\" -command \"exec %s -e %s\"\n", tk_string(app->group), app->name, use_term, app->exec);
     else
      printf(" .wmconfig.menu.%s add command -label \"%s\" -command \"exec %s\"\n", tk_string(app->group), app->name, app->exec);
   }
  }
  item++;
 }

/* finished */

 item = root->items;

 while (item->type != 0) {
  if (item->type == ITEM_MENU)
   output_entries(item->data, use_term);
  item++;
 }
 return;
}

/* First we will create the menus
   then the application entries */

void output_launcher(struct group *root, char *use_term)
{

 /* First we create our main button */

 printf("menubutton .wmconfig -text \"%s\" -menu .wmconfig.menu\n", root->name);
 printf("pack .wmconfig\n");
 printf("menu .wmconfig.menu\n");

 /* Create the menu structure and the menu buttons */

 output_menus (root);

 /* Fill the menus with the entries */

 output_entries (root, use_term);
}
